==> scala-k8s-objects_2.12-0.1.0-sources.jar: io/k8s/api/core/v1/ConfigMapProjection.scala <==
package io.k8s.api.core.v1


/** Adapts a ConfigMap into a projected volume.

The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode. */
final case class ConfigMapProjection(
  items : Option[Seq[io.k8s.api.core.v1.KeyToPath]] = None,
  name : Option[String] = None,
  optional : Option[Boolean] = None
) {

  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.core.v1.KeyToPath]) : ConfigMapProjection = copy(items = Some(value))
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.core.v1.KeyToPath*) : ConfigMapProjection = copy(items = Some(items.fold(newValues)(_ ++ newValues)))
  /** if items has a value, transforms to the result of function*/
  def mapItems(f: Seq[io.k8s.api.core.v1.KeyToPath] => Seq[io.k8s.api.core.v1.KeyToPath]) : ConfigMapProjection = copy(items = items.map(f))

  /** Returns a new data with name set to new value */
  def withName(value: String) : ConfigMapProjection = copy(name = Some(value))
  /** if name has a value, transforms to the result of function*/
  def mapName(f: String => String) : ConfigMapProjection = copy(name = name.map(f))

  /** Returns a new data with optional set to new value */
  def withOptional(value: Boolean) : ConfigMapProjection = copy(optional = Some(value))
  /** if optional has a value, transforms to the result of function*/
  def mapOptional(f: Boolean => Boolean) : ConfigMapProjection = copy(optional = optional.map(f))
}

==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/ConfigMapProjection.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Adapts a ConfigMap into a projected volume.

The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode. */
final case class ConfigMapProjection(
  items : Option[Seq[io.k8s.api.core.v1.KeyToPath]] = None,
  name : Option[String] = None,
  optional : Option[Boolean] = None
) {

  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.core.v1.KeyToPath]) : ConfigMapProjection = copy(items = Some(value))
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.core.v1.KeyToPath*) : ConfigMapProjection = copy(items = Some(items.fold(newValues)(_ ++ newValues)))
  /** if items has a value, transforms to the result of function*/
  def mapItems(f: Seq[io.k8s.api.core.v1.KeyToPath] => Seq[io.k8s.api.core.v1.KeyToPath]) : ConfigMapProjection = copy(items = items.map(f))

  /** Returns a new data with name set to new value */
  def withName(value: String) : ConfigMapProjection = copy(name = Some(value))
  /** if name has a value, transforms to the result of function*/
  def mapName(f: String => String) : ConfigMapProjection = copy(name = name.map(f))

  /** Returns a new data with optional set to new value */
  def withOptional(value: Boolean) : ConfigMapProjection = copy(optional = Some(value))
  /** if optional has a value, transforms to the result of function*/
  def mapOptional(f: Boolean => Boolean) : ConfigMapProjection = copy(optional = optional.map(f))
}

object ConfigMapProjection {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.ConfigMapProjection, T] = new Encoder[io.k8s.api.core.v1.ConfigMapProjection, T] {
        def apply(o: io.k8s.api.core.v1.ConfigMapProjection) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("name", o.name)
            .write("optional", o.optional)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ConfigMapProjection] = new Decoder[T, ConfigMapProjection] {
      def apply(t: T): Either[String, ConfigMapProjection] = for {
          obj <- ObjectReader(t)
          items <- obj.readOpt[Seq[io.k8s.api.core.v1.KeyToPath]]("items")
          name <- obj.readOpt[String]("name")
          optional <- obj.readOpt[Boolean]("optional")
      } yield ConfigMapProjection (
          items = items,
          name = name,
          optional = optional
        )
    }
}
